@@ -1,21 +1,28 @@
+# Keep imports sorted alphabetically
 import fabtools.require.deb
 import fabtools.require.files
-import fabtools.require.nginx
-import fabtools.require.postfix
-import fabtools.require.postgres
 import fabtools.require.mysql
+import fabtools.require.nginx
 import fabtools.require.nodejs
 import fabtools.require.openvz
+import fabtools.require.pkg
+import fabtools.require.postfix
+import fabtools.require.postgres
 import fabtools.require.python
 import fabtools.require.redis
+import fabtools.require.rpm
 import fabtools.require.service
 import fabtools.require.shorewall
 import fabtools.require.supervisor
 import fabtools.require.system
 import fabtools.require.users
 
-from fabtools.require.files import file
-from fabtools.require.files import directory
-from fabtools.require.users import user
-from fabtools.require.users import sudoer
+from fabtools.require.files import (
+    directory,
+    file,
+)
+from fabtools.require.users import (
+    user,
+    sudoer,
+)
 from fabtools.require.groups import group
