@@ -10,8 +10,9 @@ from __future__ import with_statement
 
 from fabric.utils import puts
 
-from fabtools.files import is_file, watch
 from fabtools.deb import *
+from fabtools.files import is_file, watch
+from fabtools.utils import run_as_root
 import fabtools.require
 
 
@@ -57,7 +58,7 @@ def ppa(name):
 
     if not is_file(source):
         package('python-software-properties')
-        sudo('add-apt-repository %s' % name)
+        run_as_root('add-apt-repository %s' % name)
         update_index()
 
 
