@@ -4,6 +4,7 @@ System users
 """
 from fabtools.files import is_file
 from fabtools.user import *
+from fabtools.utils import run_as_root
 
 import fabtools.require
 
@@ -57,5 +58,5 @@ def sudoer(username, hosts="ALL", operators="ALL", passwd=False, commands="ALL")
     spec = "%(username)s %(hosts)s=(%(operators)s) %(tags)s %(commands)s" % locals()
     filename = '/etc/sudoers.d/fabtools-%s' % username
     if is_file(filename):
-        sudo('chmod 0640 %(filename)s && rm -f %(filename)s' % locals())
-    sudo('echo "%(spec)s" >%(filename)s && chmod 0440 %(filename)s' % locals(), shell=True)
+        run_as_root('chmod 0640 %(filename)s && rm -f %(filename)s' % locals())
+    run_as_root('echo "%(spec)s" >%(filename)s && chmod 0440 %(filename)s' % locals(), shell=True)
