@@ -13,6 +13,8 @@ from __future__ import with_statement
 
 from fabric.api import *
 
+from fabtools.utils import run_as_root
+
 
 def is_running(service):
     """
@@ -26,7 +28,7 @@ def is_running(service):
             print "Service foo is running!"
     """
     with settings(hide('running', 'stdout', 'stderr', 'warnings'), warn_only=True):
-        res = sudo('service %(service)s status' % locals())
+        res = run_as_root('service %(service)s status' % locals())
         return res.succeeded
 
 
@@ -42,7 +44,7 @@ def start(service):
         if not fabtools.service.is_running('foo'):
             fabtools.service.start('foo')
     """
-    sudo('service %(service)s start' % locals())
+    run_as_root('service %(service)s start' % locals())
 
 
 def stop(service):
@@ -57,7 +59,7 @@ def stop(service):
         if fabtools.service.is_running('foo'):
             fabtools.service.stop('foo')
     """
-    sudo('service %(service)s stop' % locals())
+    run_as_root('service %(service)s stop' % locals())
 
 
 def restart(service):
@@ -74,7 +76,7 @@ def restart(service):
         else:
             fabtools.service.start('foo')
     """
-    sudo('service %(service)s restart' % locals())
+    run_as_root('service %(service)s restart' % locals())
 
 
 def reload(service):
@@ -92,7 +94,7 @@ def reload(service):
 
         The service needs to support the ``reload`` operation.
     """
-    sudo('service %(service)s reload' % locals())
+    run_as_root('service %(service)s reload' % locals())
 
 
 def force_reload(service):
@@ -110,4 +112,4 @@ def force_reload(service):
 
         The service needs to support the ``force-reload`` operation.
     """
-    sudo('service %(service)s force-reload' % locals())
+    run_as_root('service %(service)s force-reload' % locals())
